==> versatile-kernel-2.6.18.1-compiled.tar.bz2: linux-2.6.18.1/drivers/input/misc/uinput.mod.c <==
#include <linux/module.h>
#include <linux/vermagic.h>
#include <linux/compiler.h>

MODULE_INFO(vermagic, VERMAGIC_STRING);

struct module __this_module
__attribute__((section(".gnu.linkonce.this_module"))) = {
 .name = KBUILD_MODNAME,
 .init = init_module,
#ifdef CONFIG_MODULE_UNLOAD
 .exit = cleanup_module,
#endif
};

static const struct modversion_info ____versions[]
__attribute_used__
__attribute__((section("__versions"))) = {
	{ 0xe3e52f33, "struct_module" },
	{ 0x2ec7b451, "misc_deregister" },
	{ 0xf2c358d5, "misc_register" },
	{ 0xeef49e, "__strnlen_user" },
	{ 0x313341a3, "_set_bit_le" },
	{ 0xed485a8, "input_register_device" },
	{ 0x98082893, "__copy_to_user" },
	{ 0x323222ba, "mutex_unlock" },
	{ 0x9d669763, "memcpy" },
	{ 0x73e20c1c, "strlcpy" },
	{ 0xdd132261, "printk" },
	{ 0x12da5bb2, "__kmalloc" },
	{ 0xd9ce8f0c, "strnlen" },
	{ 0x8523fd53, "kmem_cache_alloc" },
	{ 0x42bb119a, "input_event" },
	{ 0x17a142df, "__copy_from_user" },
	{ 0xfa2a45e, "__memzero" },
	{ 0x5dae54b4, "mutex_lock_interruptible" },
	{ 0xc6110bdf, "input_allocate_device" },
	{ 0xb13d73c9, "malloc_sizes" },
	{ 0x6c36a5c1, "__mutex_init" },
	{ 0xc818ff24, "kmem_cache_zalloc" },
	{ 0x37a0cba, "kfree" },
	{ 0x8877f94f, "input_free_device" },
	{ 0x74b0c3ca, "input_unregister_device" },
	{ 0xc8b57c27, "autoremove_wake_function" },
	{ 0x51493d94, "finish_wait" },
	{ 0x1000e51, "schedule" },
	{ 0x8085c7b1, "prepare_to_wait" },
	{ 0x5f754e5a, "memset" },
	{ 0x6cb34e5, "init_waitqueue_head" },
	{ 0x25fa6f17, "wait_for_completion" },
	{ 0xa218bf61, "complete" },
	{ 0xb6c70a7d, "__wake_up" },
	{ 0x72270e35, "do_gettimeofday" },
};

static const char __module_depends[]
__attribute_used__
__attribute__((section(".modinfo"))) =
"depends=";

==> versatile-kernel-2.6.19.1-compiled.tar.bz2: linux-2.6.19.1/drivers/input/misc/uinput.mod.c <==
#include <linux/module.h>
#include <linux/vermagic.h>
#include <linux/compiler.h>

MODULE_INFO(vermagic, VERMAGIC_STRING);

struct module __this_module
__attribute__((section(".gnu.linkonce.this_module"))) = {
 .name = KBUILD_MODNAME,
 .init = init_module,
#ifdef CONFIG_MODULE_UNLOAD
 .exit = cleanup_module,
#endif
};

static const struct modversion_info ____versions[]
__attribute_used__
__attribute__((section("__versions"))) = {
	{ 0x528a560b, "struct_module" },
	{ 0x89b9bfa2, "misc_deregister" },
	{ 0x16cac916, "misc_register" },
	{ 0x6cef247f, "__strnlen_user" },
	{ 0x313341a3, "_set_bit_le" },
	{ 0x13a4358e, "input_ff_destroy" },
	{ 0xc20db826, "input_register_device" },
	{ 0x11f4be54, "input_ff_create" },
	{ 0x67c2fa54, "__copy_to_user" },
	{ 0x323222ba, "mutex_unlock" },
	{ 0x9d669763, "memcpy" },
	{ 0x73e20c1c, "strlcpy" },
	{ 0xdd132261, "printk" },
	{ 0x12da5bb2, "__kmalloc" },
	{ 0xd9ce8f0c, "strnlen" },
	{ 0x8523fd53, "kmem_cache_alloc" },
	{ 0xa337a526, "input_event" },
	{ 0xfbc74f64, "__copy_from_user" },
	{ 0xfa2a45e, "__memzero" },
	{ 0x5dae54b4, "mutex_lock_interruptible" },
	{ 0x254f17f8, "input_allocate_device" },
	{ 0xb13d73c9, "malloc_sizes" },
	{ 0x6c36a5c1, "__mutex_init" },
	{ 0xc818ff24, "kmem_cache_zalloc" },
	{ 0x37a0cba, "kfree" },
	{ 0x142fdc4e, "input_free_device" },
	{ 0x513a98a6, "input_unregister_device" },
	{ 0xc8b57c27, "autoremove_wake_function" },
	{ 0x51493d94, "finish_wait" },
	{ 0x1000e51, "schedule" },
	{ 0x8085c7b1, "prepare_to_wait" },
	{ 0x5f754e5a, "memset" },
	{ 0x6cb34e5, "init_waitqueue_head" },
	{ 0x25fa6f17, "wait_for_completion" },
	{ 0xa218bf61, "complete" },
	{ 0xb6c70a7d, "__wake_up" },
	{ 0x72270e35, "do_gettimeofday" },
};

static const char __module_depends[]
__attribute_used__
__attribute__((section(".modinfo"))) =
"depends=";


MODULE_INFO(srcversion, "6483CA6C5DACB6AB91E5F0D");
